""" The famous 6502! """

from .arch import Mcs6500Arch


__all__ = ['Mcs6500Arch']
